@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 # Note: Documentation has grown so massive it is now in FormBuilder.pod
@@ -12,13 +12,14 @@ use Carp;
 use strict;
 use warnings;
 no  warnings 'uninitialized';
+use Scalar::Util qw(weaken);
 
 use CGI::FormBuilder::Util;
 use CGI::FormBuilder::Field;
 use CGI::FormBuilder::Messages;
 
-our $VERSION = '3.05';
-our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
+our $VERSION = '3.06';
+our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
 our $AUTOLOAD;
 
 # Default options for FormBuilder
@@ -276,9 +277,10 @@ sub new {
             # init a new one
             $fprop{name} = "$_";
             $_ = $self->new_field(%fprop);
+            weaken($_->{_form});
         }
         debug 2, "push \@(@ftmp), $_";
-        $self->{fieldrefs}{"$_"} = $_;
+        weaken($self->{fieldrefs}{"$_"} = $_);
         push @ftmp, $_;
     }
 
@@ -375,8 +377,11 @@ sub field {
     # if we're still in here, we need to init a new field
     # push it onto our mail fields array, just like initfields()
     my $f = $self->new_field(%$args);
-    $self->{fieldrefs}{"$f"} = $f;
+    weaken($self->{fieldrefs}{"$f"} = $f);
+    weaken($f->{_form});
+    weaken($f->{fieldrefs}{"$f"});
     push @{$self->{fields}}, $f;
+    
     return $f->value;
 }
 
@@ -403,7 +408,7 @@ sub new_field {
             $args->{$k} = $v;
         }
     }
-
+    
     my $f = CGI::FormBuilder::Field->new($self, $args);
     debug 1, "created field $f";
     return $f;   # already set args above ^^^
@@ -502,7 +507,7 @@ sub header {
 
     # Forcibly require - no extra time in normal case, and if 
     # using Apache::Request this needs to be loaded anyways.
-    return '' if $::TESTING;
+    return "Content-type: text/html\n\n" if $::TESTING;
     require CGI;
     return  CGI::header(%head);    # CGI.pm MOD_PERL fanciness
 }
@@ -925,15 +930,16 @@ sub script {
 function $jsname (form) {
     var alertstr = '';
     var invalid  = 0;
+    var invalid_fields = new Array();
 
 EOJ1
     if (invalid > 0 || alertstr != '') {
 EOJ2
 
         # Check to see if we have our own jserror callback on form failure
-        # if not, then use the builtin one
+        # if not, then use the builtin one. Aka jsalert
         if (my $jse = $self->jserror) {
-            $jsfunc .= "        return $jse(form, invalid, alertstr);\n";
+            $jsfunc .= "        return $jse(form, invalid, alertstr, invalid_fields);\n";
         } else {
             # Finally, close our JavaScript if it was opened, wrapping in <script> tags
             # We do a regex trick to turn "%s" into "+invalid+"
@@ -1433,6 +1439,16 @@ sub prepare {
     $tmplvar{invalid}  = $self->invalid;
     debug 2, "\$tmplvar{required} = \$self->required";
     $tmplvar{required} = $self->required;
+
+    my $fieldsets = $self->fieldsets;
+    for my $key (keys %$fieldsets) {
+        $tmplvar{fieldset}{$key} = {
+            name => $key,
+            label => $fieldsets->{$key},
+        }
+    }
+    $tmplvar{fieldsets} = [ map $tmplvar{fieldset}{$_}, $self->fieldsets ];
+
     debug 2, "\$tmplvar{fields} = [ map \$tmplvar{field}{\$_}, \$self->field ]";
     $tmplvar{fields}   = [ map $tmplvar{field}{$_}, $self->field ];
 
@@ -1467,10 +1483,10 @@ sub render {
         $ref = 'HASH';  # tricky
         debug 2, "rewrote 'template' option since found filename";
     }
-
     # Get ourselves ready
     $self->{prepare} = $self->prepare;
-
+    # weaken($self->{prepare});
+    
     my $opt;
     if ($ref eq 'HASH') {
         # must copy to avoid destroying
@@ -1498,8 +1514,9 @@ sub render {
     puke "Bad template engine $mod: $@" if $@;
 
     # create new object
+    #CGI::FormBuilder::Template::Builtin
+    
     my $tmpl = $mod->new($opt);
-
     # Experiemental: Alter tag names as we're rendering, to support 
     # Ajaxian markup schemes that use their own tags (Backbase, Dojo, etc)
     local %CGI::FormBuilder::Util::TAGNAMES;
@@ -1507,16 +1524,24 @@ sub render {
         $CGI::FormBuilder::Util::TAGNAMES{$k} = $v;
     }
 
+
     # Call the engine's prepare too, if it exists
     # Give it the form object so it can do what it wants
     # This will have all of the prepared data in {prepare} anyways
     if ($tmpl && UNIVERSAL::can($tmpl, 'prepare')) {
         $tmpl->prepare($self);
     }
+    
+
 
     # dispatch to engine, prepend header
     debug 1, "returning $tmpl->render($self->{prepare})";
-    return $self->header . $tmpl->render($self->{prepare});
+
+    my $ret = $self->header . $tmpl->render($self->{prepare});
+    
+    #we have a circular reference but we need to kill it after setting up return
+    weaken($self->{prepare});
+    return $ret;
 }
 
 # These routines should be moved to ::Mail or something since they're rarely used
