@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Field;
@@ -50,8 +50,8 @@ no  warnings 'uninitialized';
 
 use CGI::FormBuilder::Util;
 
-our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
+our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
+our $VERSION = '3.06';
 our $AUTOLOAD;
 
 # what to generate for tag
@@ -171,7 +171,7 @@ sub othertag {
     # default settings
     $oa->{type}  ||= 'text';
     my $v = $self->{_form}->cgi_param($self->othername);
-    $v = $self->tag_value unless defined $v;
+    #$v = $self->tag_value unless defined $v;
     if ($self->sticky and defined $v) {
         $oa->{value} = $v;
     }
@@ -409,6 +409,7 @@ sub type {
 
     # Re-bless into the appropriate package
     my $pkg = __PACKAGE__ . '::' . $type;
+    $pkg =~ s/\-/_/g;  # handle HTML5 type names ala 'datetime-local'
     eval "require $pkg";
     puke "Can't load $pkg for field '$name' (type '$type'): $@" if $@;
     bless $self, $pkg;
@@ -639,6 +640,7 @@ sub jsfield {
     $jsfunc .= <<EOJS;
 $in    alertstr += '$alertstr';
 $in    invalid++;
+$in    invalid_fields.push('$jsfield');
 $in}$close_brace
 EOJS
 
@@ -730,6 +732,9 @@ sub validate () {
             unless (defined($value) && length($value)) {
                 $thisfail = ++$bad;
             }
+        } elsif (! defined $pattern) {
+            debug 2, "$field: length('$value') > 0";
+            $thisfail = ++$bad unless length($value) > 0;
         } else {
             # literal string is a literal comparison, but warn of typos...
             belch "Validation string '$pattern' may be a typo of a builtin pattern"
@@ -1013,11 +1018,11 @@ L<CGI::FormBuilder>
 
 =head1 REVISION
 
-$Id: Field.pm 91 2006-12-18 10:27:01Z nwiger $
+$Id: Field.pm 100 2007-03-02 18:13:13Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
