@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Messages;
@@ -28,8 +28,8 @@ no  warnings 'uninitialized';
 
 use CGI::FormBuilder::Util;
 
-our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
+our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
+our $VERSION = '3.06';
 our $AUTOLOAD;
 
 sub new {
@@ -147,6 +147,7 @@ Currently included with B<FormBuilder> are several different locales:
     Japanese             ja_JP
     Norwegian/Norvegian  no_NO
     Turkish              tr_TR
+    Russian              ru_RU
 
 To enable automatic localization that will detect the client's locale
 and use one of these included locales, simply turn on C<auto> messages:
@@ -287,11 +288,11 @@ L<CGI::FormBuilder>
 
 =head1 REVISION
 
-$Id: Messages.pm 91 2006-12-18 10:27:01Z nwiger $
+$Id: Messages.pm 100 2007-03-02 18:13:13Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
