@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Multi;
@@ -103,8 +103,8 @@ no  warnings 'uninitialized';
 use CGI::FormBuilder;
 use CGI::FormBuilder::Util;
 
-our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
+our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
+our $VERSION = '3.06';
 
 our %DEFAULT = (
     pagename => '_page',
@@ -121,11 +121,18 @@ sub new {
     while (ref $_[0]) {
         push @forms, shift;
     }
-    puke "Must specify at least one form to ::Multi" unless @forms;
 
     # Remaining options are form opts
     my %opt  = arghash(@_);
 
+    # If no forms, and specified number of pages, use that instead
+    if ($opt{pages}) {
+        puke "Can't specify pages and form hashrefs" if @forms;
+        my $p = 0;
+        push @forms, {} while $p++ < $opt{pages};
+    }
+    puke "Must specify at least one form or 'pages' option for ::Multi" unless @forms;
+
     # Check for CGI params
     # This is duplicated code straight out of FormBuilder.pm,
     # but it's needed here as well so we can get our _page
@@ -286,6 +293,14 @@ C<header> (which will likely be the same), and then override
 individual settings like C<fields> and C<validate> on a per-form
 basis.
 
+If you do not wish to specify any options for your forms, you
+can instead just specify the C<pages> option, for example:
+
+    my $multi = CGI::FormBuilder::Multi->new(pages => 3);
+
+With this approach, you will have to dynamically assemble each
+page as you come to them. The mailing list can help.
+
 The L</"SYNOPSIS"> above is very representative of typical usage.
 
 =head2 form()
@@ -348,11 +363,11 @@ L<CGI::FormBuilder>
 
 =head1 REVISION
 
-$Id: Multi.pm 91 2006-12-18 10:27:01Z nwiger $
+$Id: Multi.pm 100 2007-03-02 18:13:13Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2005-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
