@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Template;
@@ -51,8 +51,8 @@ use strict;
 use warnings;
 no  warnings 'uninitialized';
 
-our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
+our $REVISION = do { (my $r='$Revision: 97 $') =~ s/\D+//g; $r };
+our $VERSION = '3.0501';
 warn __PACKAGE__, " is not a real module, please read the docs\n"; 
 1;
 __END__
@@ -108,6 +108,7 @@ types are:
     Text    -  Text::Template
     TT2     -  Template Toolkit
     Fast    -  CGI::FastTemplate
+    CGI_SSI -  CGI::SSI
 
 In addition to one of these types, you can also specify a complete package name,
 in which case that module will be autoloaded and its C<new()> and C<render()>
@@ -192,15 +193,15 @@ the guts of one of the existing template engines and go from there.
 
 L<CGI::FormBuilder>, L<CGI::FormBuilder::Template::HTML>,
 L<CGI::FormBuilder::Template::Text>, L<CGI::FormBuilder::Template::TT2>,
-L<CGI::FormBuilder::Template::Fast>
+L<CGI::FormBuilder::Template::Fast>, L<CGI::FormBuilder::Template::CGI_SSI>
 
 =head1 REVISION
 
-$Id: Template.pm 91 2006-12-18 10:27:01Z nwiger $
+$Id: Template.pm 97 2007-02-06 17:10:39Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
