@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Util;
@@ -41,8 +41,8 @@ use Carp;
 require File::Basename;
 
 # Authoritative version information actually lives here
-our $VERSION = '3.05';
-our $REVISION = do { (my $r='$Revision: 91 $') =~ s/\D+//g; $r };
+our $VERSION = '3.06';
+our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
 
 # Place functions you want to export by default in the
 # @EXPORT array. Any other functions can be requested
@@ -63,12 +63,13 @@ our %TAGNAMES = ();     # holds translated tag names (experimental)
 # specified in the generation of HTML tags, and also means that this
 # module doesn't go out of date when the HTML spec changes next week.
 our @OURATTR = qw(
-    attr autofill autofillshow body bodyname buttonname caller checknum cleanopts 
-    columns cookies comment debug delete dtd errorname extraname fields
-    fieldattr fieldsubs fieldtype fieldname fieldopts fieldset fieldsets
-    font force formname growable growname header idprefix inputname invalid
-    javascript jsmessage jsname jsprefix jsfunc jshead jserror jsvalid keepextras
-    labels labelname lalign linebreaks message messages nameopts newline other othername
+    add_before_option add_after_option attr autofill autofillshow body bodyname
+    buttonname caller checknum cleanopts columns cookies comment debug delete
+    disable_enter dtd errorname extraname fields fieldattr fieldsubs fieldtype fieldname
+    fieldopts fieldset fieldsets font force formname growable growname header
+    idprefix inputname invalid javascript jsmessage jsname jsprefix jsfunc jshead
+    jserror jsvalid keepextras labels labelname lalign 
+    linebreaks message messages nameopts newline NON_EMPTY_SCRIPT other othername
     optgroups options override page pages pagename params render required
     reset resetname rowname selectname selectnum sessionidname sessionid
     smartness source sortopts static statename sticky stylesheet styleclass submit
@@ -105,6 +106,7 @@ our @CARP_NOT = qw(
     CGI::FormBuilder::Template::HTML
     CGI::FormBuilder::Template::TT2
     CGI::FormBuilder::Template::Text
+    CGI::FormBuilder::Template::CGI_SSI
     CGI::FormBuilder::Util
 );
 
@@ -522,11 +524,11 @@ L<CGI::FormBuilder>
 
 =head1 REVISION
 
-$Id: Util.pm 91 2006-12-18 10:27:01Z nwiger $
+$Id: Util.pm 100 2007-03-02 18:13:13Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
